==> dojo-1.10.6.tgz: package/cldr/nls/sr/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "сада",
	"field-weekday": "дан у недељи",
	"field-wed-relative+0": "ове среде",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-wed-relative+1": "следеће среде",
	"field-tue-relative+-1": "прошлог уторка",
	"dateFormatItem-yyyyMMdd": "dd.MM.y. G",
	"dateFormatItem-MMMdd": "dd.MMM",
	"dateFormat-long": "dd. MMMM y. G",
	"field-fri-relative+-1": "прошлог петка",
	"field-wed-relative+-1": "прошле среде",
	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"dateFormatItem-yyyyMEd": "E, d.M.y. G",
	"field-thu-relative+-1": "прошлог четвртка",
	"dateFormatItem-Md": "d/M",
	"field-era": "ера",
	"field-year": "година",
	"dateFormatItem-yyyyMMMM": "MMMM y. G",
	"dateFormatItem-MMdd": "MM-dd",
	"field-hour": "час",
	"field-sat-relative+0": "ове суботе",
	"field-sat-relative+1": "следеће суботе",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"field-thu-relative+0": "овог четвртка",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "прекосутра",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-sun-relative+0": "ове недеље",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "следеће недеље",
	"field-minute": "минут",
	"field-dayperiod": "пре подне/поподне",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "јуче",
	"dateFormatItem-h": "hh a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "прекјуче",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, M-d",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "овог петка",
	"field-fri-relative+1": "следећег петка",
	"field-day": "дан",
	"field-zone": "зона",
	"dateFormatItem-yyyyMM": "MM.y. G",
	"dateFormatItem-y": "y. G",
	"field-year-relative+-1": "Прошле године",
	"field-month-relative+-1": "Прошлог месеца",
	"dateFormatItem-hm": "hh.mm a",
	"dateFormatItem-yyyyMd": "d.M.y. G",
	"field-month": "месец",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "овог уторка",
	"field-tue-relative+1": "следећег уторка",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"field-mon-relative+0": "овог понедељка",
	"field-mon-relative+1": "следећег понедељка",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-second": "секунд",
	"field-sat-relative+-1": "прошле суботе",
	"field-sun-relative+-1": "прошле недеље",
	"field-month-relative+0": "Овог месеца",
	"field-month-relative+1": "Следећег месеца",
	"dateFormatItem-Ed": "E d.",
	"field-week": "недеља",
	"dateFormat-medium": "dd.MM.y. G",
	"field-year-relative+0": "Ове године",
	"field-week-relative+-1": "Прошле недеље",
	"dateFormatItem-yyyyM": "M.y. G",
	"field-year-relative+1": "Следеће године",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "hh.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-mon-relative+-1": "прошлог понедељка",
	"dateFormatItem-yyyy": "y. G",
	"field-week-relative+0": "Ове недеље",
	"field-week-relative+1": "Следеће недеље"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/sr/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "сада",
	"field-weekday": "дан у недељи",
	"field-wed-relative+0": "у среду",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-wed-relative+1": "следеће среде",
	"field-tue-relative+-1": "прошлог уторка",
	"dateFormatItem-yyyyMMdd": "dd.MM.y. G",
	"dateFormatItem-MMMdd": "dd.MMM",
	"dateFormat-long": "dd. MMMM y. G",
	"field-fri-relative+-1": "прошлог петка",
	"field-wed-relative+-1": "прошле среде",
	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"dateFormatItem-yyyyMEd": "E, d.M.y. G",
	"field-thu-relative+-1": "прошлог четвртка",
	"dateFormatItem-Md": "d/M",
	"field-era": "ера",
	"field-year": "година",
	"dateFormatItem-yyyyMMMM": "MMMM y. G",
	"dateFormatItem-MMdd": "MM-dd",
	"field-hour": "сат",
	"field-sat-relative+0": "у суботу",
	"field-sat-relative+1": "следеће суботе",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"field-thu-relative+0": "у четвртак",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "прекосутра",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-sun-relative+0": "у недељу",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "следеће недеље",
	"field-minute": "минут",
	"field-dayperiod": "пре подне/по подне",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "јуче",
	"dateFormatItem-h": "hh a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "прекјуче",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, M-d",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "у петак",
	"field-fri-relative+1": "следећег петка",
	"field-day": "дан",
	"field-zone": "временска зона",
	"dateFormatItem-yyyyMM": "MM.y. G",
	"dateFormatItem-y": "y. G",
	"field-year-relative+-1": "прошле године",
	"field-month-relative+-1": "прошлог месеца",
	"dateFormatItem-hm": "hh.mm a",
	"dateFormatItem-yyyyMd": "d.M.y. G",
	"field-month": "месец",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "у уторак",
	"field-tue-relative+1": "следећег уторка",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-second": "секунд",
	"field-sat-relative+-1": "прошле суботе",
	"field-sun-relative+-1": "прошле недеље",
	"field-month-relative+0": "овог месеца",
	"field-month-relative+1": "следећег месеца",
	"dateFormatItem-Ed": "E d.",
	"field-week": "недеља",
	"dateFormat-medium": "dd.MM.y. G",
	"field-year-relative+0": "ове године",
	"field-week-relative+-1": "прошле недеље",
	"dateFormatItem-yyyyM": "M.y. G",
	"field-year-relative+1": "следеће године",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "hh.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-mon-relative+-1": "прошлог понедељка",
	"dateFormatItem-yyyy": "y. G",
	"field-week-relative+0": "ове недеље",
	"field-week-relative+1": "следеће недеље"
}
//end v1.x content
);
